import 'dart:convert';
import 'dart:html' as html;
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:workflow/utils/net_util.dart';

import '../widget/hovor_extension.dart';

class BaseInfoPage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _BaseInfoPageState();
}

class _BaseInfoPageState extends State<BaseInfoPage> {
  List<BaseInfo> _items = [];

  @override
  void initState() {
    super.initState();
    _fetchDoctorInfo();
  }

  //创建item
  Widget _buildItem(String title, String content) {
    return Container(
      padding: EdgeInsets.fromLTRB(20, 20, 20, 20),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Text(
            title,
            style: TextStyle(
              color: Colors.white,
              fontSize: 40.0,
              fontWeight: FontWeight.w300,
            ),
            textAlign: TextAlign.left,
          ),
          Padding(
            padding: EdgeInsets.fromLTRB(0, 8, 0, 8),
            child: Text(
              content ?? "",
              style: TextStyle(
                color: Colors.white,
                fontSize: 15.0,
                letterSpacing: 1,
                fontWeight: FontWeight.w100,
              ),
            ),
          ),
        ],
      ),
    );
  }

  //创建Cli item
  Widget _buildCliItem(String title, String fltVersion, String wbVersion,
      String downUrl, String docUrl) {
    return Container(
      padding: EdgeInsets.fromLTRB(20, 20, 20, 20),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          _buildText(title, Colors.white, 40.0),
          Padding(
            padding: EdgeInsets.fromLTRB(0, 8, 0, 8),
            child: Column(
              children: <Widget>[
                _buildCliItemColumnOption(
                    _buildText('FlutterSDK版本要求：', Colors.white, 15.0),
                    _buildText(fltVersion, Colors.white, 15.0),
                    null),
                _buildCliItemColumnOption(
                    _buildText('WuBaSDK版本要求：', Colors.white, 15.0),
                    _buildText(wbVersion, Colors.white, 15.0),
                    null),
                _buildCliItemColumnOption(
                    _buildText('WuBaSDK下载地址：', Colors.white, 15.0),
                    _buildText(downUrl, Colors.blue, 15.0),
                    downUrl),
                _buildCliItemColumnOption(
                    _buildText('WuBaSDK文档地址：', Colors.white, 15.0),
                    _buildText(docUrl, Colors.blue, 15.0),
                    docUrl),
              ],
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildCliItemColumnOption(Widget prefixText, Widget suffixText,
      String url) {
    return Container(
      padding: EdgeInsets.fromLTRB(0, 10, 0, 10),
      alignment: Alignment.centerLeft,
      child: Row(
        children: <Widget>[
          prefixText,
          url != null ? GestureDetector(
            child: suffixText,
            onTap: () {
              if (url != null) {
                html.window.open(url, url);
              }
            },
          ).pointer : suffixText,
        ],
      ),
    );
  }

  Widget _buildText(String text, Color fontColor, double fontSize) {
    return Text(
      text ?? "",
      textAlign: TextAlign.left,
      style: TextStyle(
        color: fontColor,
        fontSize: fontSize,
        letterSpacing: 1,
        fontWeight: FontWeight.w100,
      ),
    );
  }

  _fetchDoctorInfo() async {
    try {
      String resJson = await NetUtils.get('/api/baseinfo/info');
      Map map = json.decode(resJson);
      List list = map['data'];
      List items = list.map((m) => BaseInfo.fromJson(m)).toList().where((i) =>
      i.content != null && i.content != '').toList();
      if (mounted) {
        setState(() {
          _items = items;
        });
      }
    } on Exception catch (e) {
      print(e.toString());
    }
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
        child: ListView.builder(
      itemBuilder: (_, index) {
        Widget item;
        var info = _items[index];
        if (index == 0) {
          item = _buildItem(info.title, info.content);
        } else if (index == 1) {
          // TODO 解析太重，移到build之外
          var content = info.content;
          Map map = json.decode(content);
          var fltVersion = map['fltVersion'];
          var wbVersion = map['wbVersion'];
          var downUrl = map['downUrl'];
          var docUrl = map['docUrl'];
          item =
              _buildCliItem(info.title, fltVersion, wbVersion, downUrl, docUrl);
        }
        return item;
      },
      itemCount: _items.length,
    ));
  }
}

class BaseInfo {
  String title;
  String content;

  BaseInfo.fromJson(Map<String, dynamic> json)
      : title = json['title'],
        content = json['content'];
}
