import 'dart:html';

import 'package:flutter/material.dart';
import 'package:workflow/utils/date_format_util.dart';

import '../widget/drop_down_menu.dart';
import '../widget/hovor_extension.dart';
import 'log_utils.dart';

//日志界面
class LogPage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _LogPageState();
}

class _LogPageState extends State<LogPage> {
  String _filterLevel;
  ScrollController _controller = ScrollController();

  @override
  void initState() {
    super.initState();
    logManager.onLogMsgUpdate = () {
      setState(() {});
    };
  }

  @override
  void dispose() {
    super.dispose();
    logManager.onLogMsgUpdate = null;
  }

  Widget _header(BuildContext context) {
    return Container(
      height: 60,
      color: Color.fromARGB(0xFF, 0x22, 0x22, 0x22),
      padding: const EdgeInsets.symmetric(horizontal: 10),
      child: Row(
        children: <Widget>[
          Icon(Icons.view_agenda, color: Colors.white),
          Container(width: 10),
          Text('LOGGING', style: TextStyle(color: Colors.white)),
          Expanded(child: Text('')),
          DropDownMenu(
            title: 'level',
            menuList: [
              '全部',
              WBLevel.INFO,
              WBLevel.ERROR,
              WBLevel.SUCCESS,
              WBLevel.WARNING,
              WBLevel.SERVER
            ],
            titleTextStyle: TextStyle(color: Colors.white),
            onSelected: (String s) {
              setState(() {
                _filterLevel = s;
              });
            },
          ),
          IconButton(
            icon: Icon(Icons.delete_forever, color: Colors.white),
            onPressed: () {
              setState(() {
                logManager.removeAllLog();
              });
            },
          )
        ],
      ),
    );
  }

  Widget _logBody(BuildContext context) {
    var filters = <WBLogRecord>[];
    if (_filterLevel == null || _filterLevel == '全部') {
      filters = logManager.logList;
    } else {
      filters = logManager.logList
          .where((item) => item.level == _filterLevel)
          .toList();
      print(filters);
    }

    return Expanded(
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 10),
        child: ListView.builder(
          controller: _controller,
          itemCount: filters.length,
          itemBuilder: (context, index) {
            return Container(
                margin: const EdgeInsets.only(top: 0),
                child: _logItem(context, filters[index]));
          },
        ),
      ),
    );
  }

  WBLogRecord _hoverModel;

  Widget _logItem(BuildContext context, WBLogRecord model) {
    return MouseRegion(
      onHover: (event) {
        if (_hoverModel == null || _hoverModel != model) {
          _hoverModel = model;
          setState(() {});
        }
      },
      onExit: (event) {
        _hoverModel = null;
        setState(() {});
      },
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Text(model.level, style: getTextStyle(model.level)),
              Container(height: 3),
              Text(
                  DateFormatter.stringWithDateString(
                      format: 'HH:mm:ss', dateStr: model.time),
                  style: TextStyle(color: Colors.white30))
            ],
          ),
          _copyWidget(model).pointer,
          Expanded(
            child: Text(model.message,
                style: getTextStyle(model.level), maxLines: null),
            // child: TextField(
            //   toolbarOptions: ToolbarOptions(copy: true, selectAll: true),
            //   controller: TextEditingController(text: model.message),
            //   style: getTextStyle(model.level),
            //   keyboardType: TextInputType.multiline,
            //   maxLines: null,
            //   decoration: InputDecoration.collapsed(hintText: ''),
            //   onChanged: (s) {
            //     setState(() {});
            //   },
            // ),
          ),
        ],
      ),
    );
  }

  //复制
  Widget _copyWidget(WBLogRecord model) {
    return GestureDetector(
      onTap: () {
        _copyToClipboardHack(model.message);
        Scaffold.of(context).showSnackBar(SnackBar(
          content: Text('已复制到剪切板'),
          duration: Duration(milliseconds: 2000),
          backgroundColor: Colors.grey,
        ));
      },
      child: Container(
        padding: const EdgeInsets.only(left: 5, right: 5, top: 2, bottom: 2),
        margin: const EdgeInsets.only(right: 5, left: 10),
        color: _hoverModel == model ? Colors.deepPurple : Colors.transparent,
        child: Text('复制',
            style: TextStyle(
                color: _hoverModel == model ? Colors.white : Colors.transparent,
                fontSize: 11)),
      ),
    );
  }

  bool _copyToClipboardHack(String text) {
    final textarea = new TextAreaElement();
    document.body.append(textarea);
    textarea.style.border = '0';
    textarea.style.margin = '0';
    textarea.style.padding = '0';
    textarea.style.opacity = '0';
    textarea.style.position = 'absolute';
    textarea.readOnly = true;
    textarea.value = text;
    textarea.select();
    final result = document.execCommand('copy');
    textarea.remove();
    return result;
  }

  TextStyle getTextStyle(String level) {
    if (level == WBLevel.INFO) {
      return TextStyle(color: Colors.white, fontSize: 13);
    } else if (level == WBLevel.ERROR) {
      return TextStyle(color: Colors.red, fontSize: 13);
    } else if (level == WBLevel.SUCCESS) {
      return TextStyle(color: Colors.green, fontSize: 13);
    } else if (level == WBLevel.WARNING) {
      return TextStyle(color: Colors.yellow, fontSize: 13);
    } else {
      return TextStyle(color: Colors.white, fontSize: 13);
    }
  }

  @override
  Widget build(BuildContext context) {
    Future.delayed(Duration(milliseconds: 20), () {
      _controller.jumpTo(_controller.position.maxScrollExtent);
    });
    return Expanded(child:Column(children: <Widget>[_header(context), _logBody(context)]));
  }
}
