import 'dart:async';
import 'dart:html' as html;

import 'package:dio/dio.dart';
import 'package:flutter/cupertino.dart';

import '../component/log/log_utils.dart';
import '../model/response_bean.dart';


Map<String, dynamic> optHeader = {
  'content-type': 'application/json'
};

/// used for http、ws
String _domain;
Dio _dio;
set domain(String url) {
  if (_domain != null) {
    return;
  }
  _domain = url;
  _dio = null;
}

get domain {
  return _domain ?? html.window.location.host;
}

get dio {
  return _dio ??= Dio(BaseOptions(
    connectTimeout: 5000 * 20,
    sendTimeout: 10000 * 20,
    headers: optHeader,
    baseUrl: 'http://$domain',
  ));
}

class NetUtils {
  static init(defaultHost) {
    var host = html.window.location.host;
    // IDE 启动时随机端口，与server不匹配,为了兼容IDE Debug,强制使用默认端口
    if (host.startsWith("localhost")) {
      debugPrint('IDE debug mode, ignore $host');
      domain = defaultHost;
    } else {
      domain = host;
    }
  }

  static String ws(String path) {
    return 'ws://$domain/$path';
  }

  static Future get(String url,
      {Map<String, dynamic> params, bool withCode = false}) async {
    var response;

    try {
      if (params != null) {
        response = await dio.get(url, queryParameters: params);
      } else {
        response = await dio.get(url);
      }
    } on DioError catch (e) {
      logger.error('${e.message},type:${e.type}');
      var r = ResponseBean(
          '网络请求错误', code: 0, msg: _getErrorMsgFromType(e.type));
      return withCode ? r : r.toString(); //统一处理错误并封装返回结果
    }
    return withCode ? response : response.data;
  }

  static Future post(String url, [Map<String, dynamic> params]) async {
    var response;
    try {
      if (params != null) {
            response = await dio.post(url, queryParameters: params);
          } else {
            response = await dio.post(url);
          }
    }on DioError catch (e) {
      logger.error('${e.message},type:${e.type}');
      return ResponseBean('网络请求错误',code: 0,msg: _getErrorMsgFromType(e.type)).toString();//统一处理错误并封装返回结果
    }
    return response.data;
  }

  static _getErrorMsgFromType(DioErrorType type){
    var errorMsg = '';
    switch(type) {
      case DioErrorType.CANCEL:
        errorMsg = '请求已取消';
        break;
      case DioErrorType.CONNECT_TIMEOUT:
      case DioErrorType.SEND_TIMEOUT:
      case DioErrorType.RECEIVE_TIMEOUT:
        errorMsg = '请求超时';
        break;
      case DioErrorType.RESPONSE:
        errorMsg = '服务器出错';
        break;
      case DioErrorType.DEFAULT:
      default:
        break;
    }
    return errorMsg;
  }
}